@@ -8,8 +8,8 @@ from h2.exceptions import NoAvailableStreamIDError
 from h2.settings import SettingCodes, Settings
 
 from .._backends.auto import AsyncBackend, AsyncLock, AsyncSemaphore, AsyncSocketStream
-from .._bytestreams import AsyncIteratorByteStream, PlainByteStream
-from .._exceptions import PoolTimeout, RemoteProtocolError
+from .._bytestreams import AsyncIteratorByteStream
+from .._exceptions import LocalProtocolError, PoolTimeout, RemoteProtocolError
 from .._types import URL, Headers, TimeoutDict
 from .._utils import get_logger
 from .base import AsyncByteStream, ConnectionState, NewConnectionRequired
@@ -85,16 +85,15 @@ class AsyncHTTP2Connection(AsyncBaseHTTPConnection):
         if self.state == ConnectionState.IDLE:
             self.state = ConnectionState.READY
 
-    async def arequest(
+    async def handle_async_request(
         self,
         method: bytes,
         url: URL,
-        headers: Headers = None,
-        stream: AsyncByteStream = None,
-        ext: dict = None,
+        headers: Headers,
+        stream: AsyncByteStream,
+        extensions: dict,
     ) -> Tuple[int, Headers, AsyncByteStream, dict]:
-        ext = {} if ext is None else ext
-        timeout = cast(TimeoutDict, ext.get("timeout", {}))
+        timeout = cast(TimeoutDict, extensions.get("timeout", {}))
 
         async with self.init_lock:
             if not self.sent_connection_init:
@@ -116,7 +115,9 @@ class AsyncHTTP2Connection(AsyncBaseHTTPConnection):
             h2_stream = AsyncHTTP2Stream(stream_id=stream_id, connection=self)
             self.streams[stream_id] = h2_stream
             self.events[stream_id] = []
-            return await h2_stream.arequest(method, url, headers, stream, ext)
+            return await h2_stream.handle_async_request(
+                method, url, headers, stream, extensions
+            )
         except Exception:  # noqa: PIE786
             await self.max_streams_semaphore.release()
             raise
@@ -154,12 +155,8 @@ class AsyncHTTP2Connection(AsyncBaseHTTPConnection):
         data_to_send = self.h2_state.data_to_send()
         await self.socket.write(data_to_send, timeout)
 
-    @property
-    def is_closed(self) -> bool:
-        return False
-
-    def is_connection_dropped(self) -> bool:
-        return self.socket.is_connection_dropped()
+    def is_socket_readable(self) -> bool:
+        return self.socket.is_readable()
 
     async def aclose(self) -> None:
         logger.trace("close_connection=%r", self)
@@ -270,18 +267,16 @@ class AsyncHTTP2Stream:
         self.stream_id = stream_id
         self.connection = connection
 
-    async def arequest(
+    async def handle_async_request(
         self,
         method: bytes,
         url: URL,
-        headers: Headers = None,
-        stream: AsyncByteStream = None,
-        ext: dict = None,
+        headers: Headers,
+        stream: AsyncByteStream,
+        extensions: dict,
     ) -> Tuple[int, Headers, AsyncByteStream, dict]:
-        headers = [] if headers is None else [(k.lower(), v) for (k, v) in headers]
-        stream = PlainByteStream(b"") if stream is None else stream
-        ext = {} if ext is None else ext
-        timeout = cast(TimeoutDict, ext.get("timeout", {}))
+        headers = [(k.lower(), v) for (k, v) in headers]
+        timeout = cast(TimeoutDict, extensions.get("timeout", {}))
 
         # Send the request.
         seen_headers = set(key for key, value in headers)
@@ -299,10 +294,10 @@ class AsyncHTTP2Stream:
             aiterator=self.body_iter(timeout), aclose_func=self._response_closed
         )
 
-        ext = {
-            "http_version": "HTTP/2",
+        extensions = {
+            "http_version": b"HTTP/2",
         }
-        return (status_code, headers, response_stream, ext)
+        return (status_code, headers, response_stream, extensions)
 
     async def send_headers(
         self,
@@ -313,18 +308,39 @@ class AsyncHTTP2Stream:
         timeout: TimeoutDict,
     ) -> None:
         scheme, hostname, port, path = url
-        default_port = {b"http": 80, b"https": 443}.get(scheme)
-        if port is None or port == default_port:
-            authority = hostname
-        else:
-            authority = b"%s:%d" % (hostname, port)
+
+        # In HTTP/2 the ':authority' pseudo-header is used instead of 'Host'.
+        # In order to gracefully handle HTTP/1.1 and HTTP/2 we always require
+        # HTTP/1.1 style headers, and map them appropriately if we end up on
+        # an HTTP/2 connection.
+        authority = None
+
+        for k, v in headers:
+            if k == b"host":
+                authority = v
+                break
+
+        if authority is None:
+            # Mirror the same error we'd see with `h11`, so that the behaviour
+            # is consistent. Although we're dealing with an `:authority`
+            # pseudo-header by this point, from an end-user perspective the issue
+            # is that the outgoing request needed to include a `host` header.
+            raise LocalProtocolError("Missing mandatory Host: header")
 
         headers = [
             (b":method", method),
             (b":authority", authority),
             (b":scheme", scheme),
             (b":path", path),
-        ] + [(k, v) for k, v in headers if k not in (b"host", b"transfer-encoding")]
+        ] + [
+            (k, v)
+            for k, v in headers
+            if k
+            not in (
+                b"host",
+                b"transfer-encoding",
+            )
+        ]
         end_stream = not has_body
 
         await self.connection.send_headers(self.stream_id, headers, end_stream, timeout)
