@@ -1,8 +1,18 @@
 import warnings
 from ssl import SSLContext
-from typing import Iterator, Callable, Dict, List, Optional, Set, Tuple, cast
+from typing import (
+    Iterator,
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Set,
+    Tuple,
+    Union,
+    cast,
+)
 
-from .._backends.sync import SyncLock, SyncSemaphore
+from .._backends.sync import SyncBackend, SyncLock, SyncSemaphore
 from .._backends.base import lookup_sync_backend
 from .._exceptions import LocalProtocolError, PoolTimeout, UnsupportedProtocol
 from .._threadlock import ThreadLock
@@ -38,7 +48,8 @@ class ResponseByteStream(SyncByteStream):
         callback: Callable,
     ) -> None:
         """
-        A wrapper around the response stream that we return from `.request()`.
+        A wrapper around the response stream that we return from
+        `.handle_request()`.
 
         Ensures that when `stream.close()` is called, the connection pool
         is notified via a callback.
@@ -67,24 +78,32 @@ class SyncConnectionPool(SyncHTTPTransport):
     """
     A connection pool for making HTTP requests.
 
-    **Parameters:**
-
-    * **ssl_context** - `Optional[SSLContext]` - An SSL context to use for
-    verifying connections.
-    * **max_connections** - `Optional[int]` - The maximum number of concurrent
-    connections to allow.
-    * **max_keepalive_connections** - `Optional[int]` - The maximum number of
-    connections to allow before closing keep-alive connections.
-    * **keepalive_expiry** - `Optional[float]` - The maximum time to allow
-    before closing a keep-alive connection.
-    * **http2** - `bool` - Enable HTTP/2 support.
-    * **uds** - `str` - Path to a Unix Domain Socket to use instead of TCP sockets.
-    * **local_address** - `Optional[str]` - Local address to connect from. Can
-    also be used to connect using a particular address family. Using
-    `local_address="0.0.0.0"` will connect using an `AF_INET` address (IPv4),
-    while using `local_address="::"` will connect using an `AF_INET6` address
-    (IPv6).
-    * **backend** - `str` - A name indicating which concurrency backend to use.
+    Parameters
+    ----------
+    ssl_context:
+        An SSL context to use for verifying connections.
+    max_connections:
+        The maximum number of concurrent connections to allow.
+    max_keepalive_connections:
+        The maximum number of connections to allow before closing keep-alive
+        connections.
+    keepalive_expiry:
+        The maximum time to allow before closing a keep-alive connection.
+    http1:
+        Enable/Disable HTTP/1.1 support. Defaults to True.
+    http2:
+        Enable/Disable HTTP/2 support. Defaults to False.
+    uds:
+        Path to a Unix Domain Socket to use instead of TCP sockets.
+    local_address:
+        Local address to connect from. Can also be used to connect using a particular
+        address family. Using ``local_address="0.0.0.0"`` will connect using an
+        ``AF_INET`` address (IPv4), while using ``local_address="::"`` will connect
+        using an ``AF_INET6`` address (IPv6).
+    retries:
+        The maximum number of retries when trying to establish a connection.
+    backend:
+        A name indicating which concurrency backend to use.
     """
 
     def __init__(
@@ -93,11 +112,13 @@ class SyncConnectionPool(SyncHTTPTransport):
         max_connections: int = None,
         max_keepalive_connections: int = None,
         keepalive_expiry: float = None,
+        http1: bool = True,
         http2: bool = False,
         uds: str = None,
         local_address: str = None,
+        retries: int = 0,
         max_keepalive: int = None,
-        backend: str = "sync",
+        backend: Union[SyncBackend, str] = "sync",
     ):
         if max_keepalive is not None:
             warnings.warn(
@@ -106,18 +127,26 @@ class SyncConnectionPool(SyncHTTPTransport):
             )
             max_keepalive_connections = max_keepalive
 
+        if isinstance(backend, str):
+            backend = lookup_sync_backend(backend)
+
         self._ssl_context = SSLContext() if ssl_context is None else ssl_context
         self._max_connections = max_connections
         self._max_keepalive_connections = max_keepalive_connections
         self._keepalive_expiry = keepalive_expiry
+        self._http1 = http1
         self._http2 = http2
         self._uds = uds
         self._local_address = local_address
+        self._retries = retries
         self._connections: Dict[Origin, Set[SyncHTTPConnection]] = {}
         self._thread_lock = ThreadLock()
-        self._backend = lookup_sync_backend(backend)
+        self._backend = backend
         self._next_keepalive_check = 0.0
 
+        if not (http1 or http2):
+            raise ValueError("Either http1 or http2 must be True.")
+
         if http2:
             try:
                 import h2  # noqa: F401
@@ -153,20 +182,22 @@ class SyncConnectionPool(SyncHTTPTransport):
     ) -> SyncHTTPConnection:
         return SyncHTTPConnection(
             origin=origin,
+            http1=self._http1,
             http2=self._http2,
             uds=self._uds,
             ssl_context=self._ssl_context,
             local_address=self._local_address,
+            retries=self._retries,
             backend=self._backend,
         )
 
-    def request(
+    def handle_request(
         self,
         method: bytes,
         url: URL,
-        headers: Headers = None,
-        stream: SyncByteStream = None,
-        ext: dict = None,
+        headers: Headers,
+        stream: SyncByteStream,
+        extensions: dict,
     ) -> Tuple[int, Headers, SyncByteStream, dict]:
         if url[0] not in (b"http", b"https"):
             scheme = url[0].decode("latin-1")
@@ -175,8 +206,7 @@ class SyncConnectionPool(SyncHTTPTransport):
             raise LocalProtocolError("Missing hostname in URL.")
 
         origin = url_to_origin(url)
-        ext = {} if ext is None else ext
-        timeout = cast(TimeoutDict, ext.get("timeout", {}))
+        timeout = cast(TimeoutDict, extensions.get("timeout", {}))
 
         self._keepalive_sweep()
 
@@ -197,21 +227,23 @@ class SyncConnectionPool(SyncHTTPTransport):
                     logger.trace("reuse connection=%r", connection)
 
             try:
-                response = connection.request(
-                    method, url, headers=headers, stream=stream, ext=ext
+                response = connection.handle_request(
+                    method, url, headers=headers, stream=stream, extensions=extensions
                 )
             except NewConnectionRequired:
                 connection = None
-            except Exception:  # noqa: PIE786
+            except BaseException:  # noqa: PIE786
+                # See https://github.com/encode/httpcore/pull/305 for motivation
+                # behind catching 'BaseException' rather than 'Exception' here.
                 logger.trace("remove from pool connection=%r", connection)
                 self._remove_from_pool(connection)
                 raise
 
-        status_code, headers, stream, ext = response
+        status_code, headers, stream, extensions = response
         wrapped_stream = ResponseByteStream(
             stream, connection=connection, callback=self._response_closed
         )
-        return status_code, headers, wrapped_stream, ext
+        return status_code, headers, wrapped_stream, extensions
 
     def _get_connection_from_pool(
         self, origin: Origin
@@ -227,7 +259,15 @@ class SyncConnectionPool(SyncHTTPTransport):
                 seen_http11 = True
 
             if connection.state == ConnectionState.IDLE:
-                if connection.is_connection_dropped():
+                if connection.is_socket_readable():
+                    # If the socket is readable while the connection is idle (meaning
+                    # we don't expect the server to send any data), then the only valid
+                    # reason is that the other end has disconnected, and is readable
+                    # because it is ready to return the b"" disconnect indicator, which
+                    # means we should drop the connection too.
+                    # (For a detailed run-through of what a "readable" socket is, and
+                    # why this is the best thing for us to do here, see:
+                    # https://github.com/encode/httpx/pull/143#issuecomment-515181778)
                     logger.trace("removing dropped idle connection=%r", connection)
                     # IDLE connections that have been dropped should be
                     # removed from the pool.
